package backstage_model

import "github.com/gogf/gf/os/gtime"

// LittleRedFind  所有分页查询接收信息类型
type LittleRedFind struct {
	IndexPage int `v:"required#页码不能为空"`
	PageSize  int `v:"required#每页展示行数不能为空"`
	LittleRed *RequestRedFind
}

// RequestRedFind 查询请求参数
type RequestRedFind struct {
	// 平台id，与third_platform_info中的id相同,小红书的ID
	PlatformId        string   `orm:"platform_id"                json:"platformId"`
	PlatformAccountId string   `orm:"platform_account_id"        json:"platformAccountId"` // 在平台上的账号（自己本地库）
	PlatformNickname  string   `orm:"platform_nickname"          json:"platformNickname"`  // 在平台上的昵称
	SubmitDate        []string `orm:"submit_date"                json:"submitDate"`        // 提交时间
	FansCount         []string `orm:"fans_count"                 json:"fansCount"`         // 粉丝数
	GotLikeCount      int64    `orm:"got_like_count"             json:"gotLikeCount"`      // (点)赞(收)藏数
	HomePageUrl       string   `orm:"home_page_url"              json:"homePageUrl"`       // 主页链接
	SkilledAt         []string `orm:"skilled_at"                 json:"skilledAt"`         // 擅长领域(info_tallent_skilled_area表中的id的数组)
	VisitStoreRegion  string   `orm:"visit_store_region"  json:"visitStoreRegion"`         // 探店区域，取region_info表中的self_code
	AddedStatus       int      `orm:"added_status"               json:"addedStatus"`       // 上架状态
	TalentId          string   `orm:"talent_id,unique"           json:"talentId"`          // 达人账号id(talent_info表id值)
}

// ResponseRedFind 查询返回参数
type ResponseRedFind struct {
	// 平台id，与third_platform_info中的id相同,小红书的ID，1是小红书，2是抖音
	PlatformId        string      `orm:"platform_id"                json:"platformId"`
	PlatformAccountId string      `orm:"platform_account_id"        json:"platformAccountId"` // 在平台上的账号（平台本身ID）
	PlatformNickname  string      `orm:"platform_nickname"          json:"platformNickname"`  // 在平台上的昵称
	SubmitDate        *gtime.Time `orm:"submit_date"                json:"submitDate"`        // 提交时间
	FansCount         string      `orm:"fans_count"                 json:"fansCount"`         // 粉丝数
	GotLikeCount      int64       `orm:"got_like_count"             json:"gotLikeCount"`      // (点)赞(收)藏数
	HomePageUrl       string      `orm:"home_page_url"              json:"homePageUrl"`       // 主页链接
	SkilledAt         string      `orm:"skilled_at"                 json:"skilledAt"`         // 擅长领域(info_tallent_skilled_area表中的id的数组)
	VisitStoreRegion  int         `orm:"visit_store_region"  json:"visitStoreRegion"`         // 探店区域，取region_info表中的self_code
	TalentId          int         `orm:"talent_id,unique"           json:"talentId"`          // 达人账号id(talent_info表id值)
}

// RemoveAccountLittleRed 下架状态操作接收参数,以及审核界面接收参数
type RemoveAccountLittleRed struct {
	PlatformAccountId string `v:"required#平台ID不能为空"`
	Message           string
	Status            string
}

// ResponsePlatformLittleRedBookAccountInfo 单个查询所有信息返回参数
type ResponsePlatformLittleRedBookAccountInfo struct {
	RedBookId               int         `orm:"red_book_id,primary"        json:"redBookId"`               //
	PlatformId              int         `orm:"platform_id"                json:"platformId"`              // 平台id，与third_platform_info中的id相同
	PlatformAccountId       string      `orm:"platform_account_id"        json:"platformAccountId"`       // 在平台上的账号
	PlatformNickname        string      `orm:"platform_nickname"          json:"platformNickname"`        // 在平台上的昵称
	HomePageUrl             string      `orm:"home_page_url"              json:"homePageUrl"`             // 主页链接
	FansCount               int64       `orm:"fans_count"                 json:"fansCount"`               // 粉丝数
	GotLikeCount            int64       `orm:"got_like_count"             json:"gotLikeCount"`            // (点)赞(收)藏数
	NoteCount               int64       `orm:"note_count"                 json:"noteCount"`               // 笔记总量
	IsSupportReporting      int         `orm:"is_support_reporting"       json:"isSupportReporting"`      // 是否支持报备
	IsSupportLive           int         `orm:"is_support_live"            json:"isSupportLive"`           // 是否支持直播
	CanMakeVideo            int         `orm:"can_make_video"             json:"canMakeVideo"`            // 是否可以制作视频
	IsAppearInVideo         int         `orm:"is_appear_in_video"         json:"isAppearInVideo"`         // 是否出镜
	SkilledAt               string      `orm:"skilled_at"                 json:"skilledAt"`               // 擅长领域(info_tallent_skilled_area表中的id的数组)  {0,不限。1,母婴。2，美妆护肤。3，时尚穿搭。4，旅游。5，美食。6，数码科技。7，健康养生。8，情感。9，宠物。10，运动健身。11，家居生活。12，搞笑。13，音乐  }
	HomePageCaptureUrl      string      `orm:"home_page_capture_url"      json:"homePageCaptureUrl"`      // 主页截图链接
	AccountFrom             string      `orm:"account_from"               json:"accountFrom"`             // 账号来源(仅B端批量上传的账号需要填写)
	PriceImageText          int64       `orm:"price_image_text"           json:"priceImageText"`          // 图文价格
	PriceVideo              int64       `orm:"price_video"                json:"priceVideo"`              // 视频价格
	PriceReportingImageText int64       `orm:"price_reporting_image_text" json:"priceReportingImageText"` // 报备图文价格
	PriceReportingVideo     int64       `orm:"price_reporting_video"      json:"priceReportingVideo"`     // 报备视频价格
	PriceLive               int64       `orm:"price_live"                 json:"priceLive"`               // 直播价格
	SubmitDate              *gtime.Time `orm:"submit_date"                json:"submitDate"`              // 提交时间
	ExamineFailAdminId      int         `orm:"examine_fail_admin_id"      json:"examineFailAdminId"`      // 审核失败操作管理员id(user表中的id)
	ExamineDate             *gtime.Time `orm:"examine_date"             json:"examineDate"`               // 审核日期
	ExamineFailReason       string      `orm:"examine_fail_reason"        json:"examineFailReason"`       // 审核失败原因
	UpdatedAt               *gtime.Time `orm:"updated_at"                 json:"updatedAt"`               // 更新时间
	ExamineSucAdminId       int         `orm:"examine_suc_admin_id"       json:"examineSucAdminId"`       // 审核成功操作管理员id(user表中的id)
	TalentId                int         `orm:"talent_id,unique"           json:"talentId"`                // 达人账号id(talent_info表id值)
}
