package backstage_model

import "github.com/gogf/gf/os/gtime"

// ZhihuFind  所有分页查询接收信息类型
type ZhihuFind struct {
	IndexPage int `v:"required#页码不能为空"`
	PageSize  int `v:"required#每页展示行数不能为空"`
	Zhihu     *RequestZhihuFind
}

// RequestZhihuFind 查询请求参数
type RequestZhihuFind struct {
	// 平台id，与third_platform_info中的id相同,小红书的ID
	PlatformId        string   `orm:"platform_id"                json:"platformId"`
	PlatformAccountId string   `orm:"platform_account_id"        json:"platformAccountId"` // 在平台上的账号（自己本地库）
	PlatformNickname  string   `orm:"platform_nickname"          json:"platformNickname"`  // 在平台上的昵称
	SubmitDate        []string `orm:"submit_date"                json:"submitDate"`        // 提交时间
	FansCount         []string `orm:"fans_count"                 json:"fansCount"`         // 粉丝数
	GotLikeCount      int64    `orm:"got_like_count"             json:"gotLikeCount"`      // (点)赞(收)藏数
	HomePageUrl       string   `orm:"home_page_url"              json:"homePageUrl"`       // 主页链接
	VisitStoreRegion  string   `orm:"visit_store_region"  json:"visitStoreRegion"`         // 探店区域，取region_info表中的self_code
	AddedStatus       int      `orm:"added_status"               json:"addedStatus"`       // 上架状态
	TalentId          string   `orm:"talent_id,unique"           json:"talentId"`          // 达人账号id(talent_info表id值)
}

// ResponseZhihuFind 查询请求参数
type ResponseZhihuFind struct {
	// 平台id，与third_platform_info中的id相同,小红书的ID，1是小红书，2是抖音
	PlatformId        string      `orm:"platform_id"                json:"platformId"`
	PlatformAccountId string      `orm:"platform_account_id"        json:"platformAccountId"` // 在平台上的账号（平台本身ID）
	PlatformNickname  string      `orm:"platform_nickname"          json:"platformNickname"`  // 在平台上的昵称
	SubmitDate        *gtime.Time `orm:"submit_date"                json:"submitDate"`        // 提交时间
	FansCount         string      `orm:"fans_count"                 json:"fansCount"`         // 粉丝数
	GotLikeCount      int64       `orm:"got_like_count"             json:"gotLikeCount"`      // (点)赞(收)藏数
	HomePageUrl       string      `orm:"home_page_url"              json:"homePageUrl"`       // 主页链接
	VisitStoreRegion  int         `orm:"visit_store_region"  json:"visitStoreRegion"`         // 探店区域，取region_info表中的self_code
	TalentId          int         `orm:"talent_id,unique"           json:"talentId"`          // 达人账号id(talent_info表id值)
}

// RemoveAccountZhihu 下架状态操作接收参数
type RemoveAccountZhihu struct {
	PlatformAccountId string `v:"required#平台ID不能为空"`
	Message           string
	Status            string
}

// ResponsePlatformZhihuAccountInfo 单个查询返回的信息参数
type ResponsePlatformZhihuAccountInfo struct {
	ZhihuId                   int         `orm:"zhihu_id,primary"             json:"zhihuId"`                   //
	PlatformId                int         `orm:"platform_id"                  json:"platformId"`                // 平台id，与third_platform_info中的id相同
	PlatformAccountId         string      `orm:"platform_account_id"          json:"platformAccountId"`         // 在平台上的账号
	PlatformNickname          string      `orm:"platform_nickname"            json:"platformNickname"`          // 在平台上的昵称
	HomePageUrl               string      `orm:"home_page_url"                json:"homePageUrl"`               // 主页链接
	FansCount                 int64       `orm:"fans_count"                   json:"fansCount"`                 // 粉丝数
	GotAgreeCount             int64       `orm:"got_agree_count"              json:"gotAgreeCount"`             // 被赞同总数
	GotLikeCount              int64       `orm:"got_like_count"               json:"gotLikeCount"`              // 被喜欢总数
	GotCollectCount           int64       `orm:"got_collect_count"            json:"gotCollectCount"`           // 被收藏总数
	AnswerCount               int64       `orm:"answer_count"                 json:"answerCount"`               // 回答总数
	CreativeLevel             int         `orm:"creative_level"               json:"creativeLevel"`             // 创作等级
	TotalReadPlayCount        int64       `orm:"total_read_play_count"        json:"totalReadPlayCount"`        // 总阅读播放量
	HomePageCaptureUrl        string      `orm:"home_page_capture_url"        json:"homePageCaptureUrl"`        // 主页截图
	AccountFrom               string      `orm:"account_from"                 json:"accountFrom"`               // 账号来源(仅B端批量上传的账号需要填写)
	PriceOriginTextAnswer     int64       `orm:"price_origin_text_answer"     json:"priceOriginTextAnswer"`     // 原创图文回答报价
	PriceOriginVideoAnswer    int64       `orm:"price_origin_video_answer"    json:"priceOriginVideoAnswer"`    // 原创视频回答报价
	PriceAnswer               int64       `orm:"price_answer"                 json:"priceAnswer"`               // 直发回答报价
	PriceAgreement            int64       `orm:"price_agreement"              json:"priceAgreement"`            // 赞同报价
	PriceOriginSpecialArticle int64       `orm:"price_origin_special_article" json:"priceOriginSpecialArticle"` // 原创专栏文章报价
	PriceSpecialArticle       int64       `orm:"price_special_article"        json:"priceSpecialArticle"`       // 直发专栏文章报价
	SubmitDate                *gtime.Time `orm:"submit_date"                  json:"submitDate"`                // 提交时间
	ExamineFailAdminId        int         `orm:"examine_fail_admin_id"        json:"examineFailAdminId"`        // 审核失败操作管理员id(user表中的id)
	ExamineDate               *gtime.Time `orm:"examine_date"             json:"examineDate"`                   // 审核日期
	ExamineFailReason         string      `orm:"examine_fail_reason"          json:"examineFailReason"`         // 审核失败原因
	UpdatedAt                 *gtime.Time `orm:"updated_at"                   json:"updatedAt"`                 // 更新时间
	ExamineSucAdminId         int         `orm:"examine_suc_admin_id"         json:"examineSucAdminId"`         // 审核成功操作管理员id(user表中的id)
	TalentId                  int         `orm:"talent_id,unique"             json:"talentId"`                  // 达人账号id(talent_info表的id值)
}
