package talent_model

import (
	"github.com/gogf/gf/database/gdb"
	"github.com/gogf/gf/os/gtime"
	"github.com/gogf/gf/util/gmeta"
)

type ConfirmReceiveSampleData struct {
	OrderId     int `json:"order_id"`
	ConfirmCode int `json:"confirm_code"`
}

type UploadDraftData struct {
	OrderId    int    `json:"order_id"`      // 订单id
	OnlineLink string `json:"online_link"`   // 在线文档链接
}

type UploadArticleData struct {
	OrderId     int64    `json:"order_id"`   // 订单id
	ArticleUrls string `json:"article_urls"`  //文章内容(视频、图片)链接
}

type UploadLinkData struct {
	OrderId		int64 `json:"order_id"`       // 订单id
	LinkUrl     string `json:"link_url"`      // 作品发布链接
	PhotoLink   string `json:"photo_link"`    // 收录截图(仅小红书才有)
}

type UploadDataData struct {
	OrderId    int64  `json:"order_id"`    // 订单id
	PostLink   string `json:"post_link"`   // 作品发布链接
	PhotoLink  string `json:"photo_link"`  // 收录截图(仅小红书才有)
	LikeNumber int    `json:"like_number"` // 点赞数
	LittleEye  int    `json:"little_eye"`  // 小眼睛
	CommitNum  int    `json:"commit_num"`  // 评论数
	CollectNum int    `json:"collect_num"` // 收藏数
	DataLink   string `json:"data_link"`   // 数据截图
}

type SamplesReturnPostInfo struct {
	OrderId        int    `json:"order_id"`        // 订单id
	ExpressCompany string `json:"express_company"` // 快递公司名称
	ExpressNumber  string `json:"express_number"`  // 快递单号
}

type OrderAndProcedureInfo struct {
	gmeta.Meta             `orm:"table:order_info"`
	OrderId                uint64                `json:"order_id"`                  //
	TaskId                 int                   `json:"task_id"`                   // 任务id
	TalentId               int                   `json:"talent_id"`                  // 达人id
	OrderStatus            int                   `json:"order_status"`              // 订单状态
	ProcedureInfo          *OrderProcedureInfo   `orm:"with:order_id=order_id"`
}

type OrderLinkInfoData struct {
	PostLink     string      `json:"post_link"`     // 发布链接
	PhotoLink    string      `json:"photo_link"`    // 图片链接
}
type OrderDataAuditData struct {
	LikeNumber   int         `json:"like_number"`   // 点赞数
	LittleEye    int         `json:"littleEye"`    // 小眼睛
	CommitNum    int         `json:"commitNum"`    // 评论数
	CollectNum   int         `json:"collectNum"`   // 收藏数
	DataLink     string      `json:"dataLink"`     // 数据截图
	AuditStatus  int         `json:"auditStatus"`  // 审核状态 1待审核 2审核通过 3审核失败
	AuditOpinion string      `json:"auditOpinion"` // 数据质检审核意见
	CreatedAt    *gtime.Time `json:"createdAt"`    // 创建时间(发货时间)
	ConfirmTime  *gtime.Time `json:"confirmTime"`  // 确认收获时间
}

type OrderDataAuditCombineData struct {
	OrderLinkInfoData *OrderLinkInfoData
	OrderDataAuditData *OrderDataAuditData
}

type OrderIncomeDetailInfo struct {
	OrderIncome int `json:"order_income"`      // 订单稿费
	DeductList gdb.Result `json:"deduct_list"` // 扣费列表
	RealIncome int `json:"real_income"`        // 实际收入
	OrderCompleteDate *gtime.Time `json:"order_complete_date"`
}