package talent_model

import "github.com/wechatpay-apiv3/wechatpay-go/services/payments/jsapi"

// WxPrepayRequestData 达人端微信支付请求发到服务端的数据
type WxPrepayRequestData struct {
	TaskId           int    `json:"task_id" v:""`           // 任务id
	PlatformNickname string `json:"platform_nickname"` // 达人在社媒平台的昵称
	BuySamplesCost   int64  `json:"buy_samples_cost"`  // 拍单费用
}

type WxPrepayResponseData struct {
	OutTradeNo string `json:"out_trade_no"`
	WxResp *jsapi.PrepayWithRequestPaymentResponse `json:"wx_resp"`
}

type ResultResource struct {
	Algorithm      string `json:"algorithm"`       // 加密算法类型, 对开启结果数据进行加密的加密算法，目前只支持AEAD_AES_256_GCM 示例值：AEAD_AES_256_GCM
	Ciphertext     string `json:"ciphertext"`      // 数据密文, Base64编码后的开启/停用结果数据密文
	AssociatedData string `json:"associated_data"` // 附加数据
	OriginalType   string `json:"original_type"`   // 原始回调类型，为transaction
	Nonce          string `json:"nonce"`           // 加密使用的随机串
}

// WxPayResultData 微信的支付通知数据
type WxPayResultData struct {
	Id           string          `json:"id"`            //通知id
	CreateTime   string          `json:"create_time"`   //创建时间
	EventType    string          `json:"event_type"`    // 通知的类型，支付成功通知的类型为TRANSACTION.SUCCESS
	ResourceType string          `json:"resource_type"` // 通知的资源数据类型，支付成功通知为encrypt-resource
	Resource     *ResultResource `json:"resource"`      // 通知资源数据 json格式
	Summary      string          `json:"summary"`       // 回调摘要 示例值：支付成功
}

// WxPayResultResponse 微信支付通知应答数据
type WxPayResultResponse struct {
	Code string `json:"code"`
	Message string `json:"message"`
}