package backstage_service

import (
	"github.com/gogf/gf/frame/g"
	"youngmini_server/app/model/backstage_model"
	"youngmini_server/app/utils"
)

var Tiktok = serviceTiktok{}

type serviceTiktok struct{}

// FindAllTiktok 查询所有
func (s *serviceTiktok) FindAllTiktok(tiktok *backstage_model.TiktokFind) ([]*backstage_model.ResponseTiktokFind, int, error) {
	var res []*backstage_model.ResponseTiktokFind
	number, err := utils.RelyNumber(2)
	if err != nil {
		return nil, 0, err
	}
	g.DB().SetDebug(true)
	err = g.DB().Model("platform_tiktok_account_info").LeftJoin("talent_info", "talent_id = talent_info.id").
		OmitEmpty().Where("talent_id IN(?)", number).
		Fields("`platform_id`,`platform_account_id`,`platform_nickname`,`submit_date`,`fans_count`,`got_like_count`,`home_page_url`,`skilled_at`,`talent_id`,visit_store_region").
		Page(tiktok.IndexPage, tiktok.PageSize).OrderDesc("talent_id").Scan(&res)
	if err != nil {
		return nil, 0, err
	}
	var result []*backstage_model.ResponseTiktokFind
	err = g.DB().Model("platform_tiktok_account_info").LeftJoin("talent_info", "talent_id = talent_info.id").OmitEmpty().Where("talent_id IN(?)", number).
		OrderDesc("talent_id").Scan(&result)
	if err != nil {
		return nil, 0, err
	}
	num := len(result)
	return res, num, nil
}

// FindByConditionTiktok 根据查询条件查询
func (s *serviceTiktok) FindByConditionTiktok(tiktok *backstage_model.TiktokFind) ([]*backstage_model.ResponseTiktokFind, int, error) {
	var res []*backstage_model.ResponseTiktokFind
	if tiktok.Tiktok == nil {
		res, num, err := s.FindAllTiktok(tiktok)
		if err != nil {
			return nil, 0, err
		}
		return res, num, nil
	}
	number, err := utils.RelyNumber(2)
	if err != nil {
		return nil, 0, err
	}
	g.DB().SetDebug(true)
	// 拼接数据库查询字符串语句
	contact := s.contact(tiktok.Tiktok)
	err = g.DB().Model("platform_tiktok_account_info").LeftJoin("talent_info", "talent_id = talent_info.id").
		OmitEmpty().Where(contact).Where("talent_id IN(?)", number).Fields("`platform_id`,`platform_account_id`,`platform_nickname`,`submit_date`,`fans_count`,`got_like_count`,`home_page_url`,`skilled_at`,`talent_id`,visit_store_region").
		Page(tiktok.IndexPage, tiktok.PageSize).OrderDesc("talent_id").Scan(&res)
	if err != nil {
		return nil, 0, err
	}
	var result []*backstage_model.ResponseTiktokFind
	err = g.DB().Model("platform_tiktok_account_info").LeftJoin("talent_info", "talent_id = talent_info.id").
		OmitEmpty().Where(contact).Where("talent_id IN(?)", number).
		Scan(&result)
	if err != nil {
		return nil, 0, err
	}
	num := len(result)
	return res, num, nil
}

// RemoveAccount 账号下架操作
func (s *serviceTiktok) RemoveAccount(status *backstage_model.RemoveAccountTiktok) error {
	g.DB().SetDebug(true)
	_, err := g.DB().Model("platform_tiktok_account_info").
		Data(g.Map{"examine_status": "3", "examine_fail_reason": status.Message}).
		Where("platform_account_id", status.PlatformAccountId).Update()
	if err != nil {
		return err
	}
	return nil
}

// 拼接数据库数据库where语句字符串
func (s *serviceTiktok) contact(tiktok *backstage_model.RequestTiktokFind) string {
	var res []string
	if tiktok.PlatformAccountId != "" {
		res = append(res, "platform_account_id="+tiktok.PlatformAccountId)
	}
	if tiktok.TalentId != "" {
		res = append(res, "talent_id="+tiktok.TalentId)
	}
	if len(tiktok.SubmitDate) != 0 {
		res = append(res, "submit_date>'"+tiktok.SubmitDate[0]+" 00:00:00' and "+
			"submit_date<'"+tiktok.SubmitDate[1]+" 23:59:59'")
	}
	if len(tiktok.FansCount) != 0 {
		res = append(res, "fans_count>="+tiktok.FansCount[0]+" and fans_count<="+tiktok.FansCount[1])
	}
	if tiktok.VisitStoreRegion != "" {
		res = append(res, "visit_store_region="+tiktok.VisitStoreRegion)
	}
	if len(tiktok.SkilledAt) != 0 {
		// JSON_CONTAINS包含语句
		var temp string
		for index, value := range tiktok.SkilledAt {
			if index == 0 {
				temp = "JSON_CONTAINS(skilled_at,'" + value + "')"
			} else {
				temp = " OR JSON_CONTAINS(skilled_at,'" + value + "')"
			}
		}
		res = append(res, "("+temp+")")
	}
	var result string
	for _, value := range res {
		result += " and " + value
	}
	return result
}

// FindAllById 单个查询所有
func (s *serviceTiktok) FindAllById(tiktok *backstage_model.RemoveAccountTiktok) (*backstage_model.ResponsePlatformTiktokAccountInfo, error) {
	var res *backstage_model.ResponsePlatformTiktokAccountInfo
	err := g.DB().Model("platform_tiktok_account_info").Where("talent_id", tiktok.PlatformAccountId).Scan(&res)
	if err != nil {
		return nil, err
	}
	return res, nil
}
