package backstage_service

import (
	"github.com/gogf/gf/frame/g"
	"youngmini_server/app/model/backstage_model"
	"youngmini_server/app/utils"
)

var Weibo = serviceWeibo{}

type serviceWeibo struct{}

// FindAllWeibo 查询所有
func (s *serviceWeibo) FindAllWeibo(weibo *backstage_model.WeiboFind) ([]*backstage_model.ResponseWeiboFind, int, error) {
	var res []*backstage_model.ResponseWeiboFind
	number, err := utils.RelyNumber(3)
	if err != nil {
		return nil, 0, err
	}
	g.DB().SetDebug(true)
	err = g.DB().Model("platform_weibo_account_info").LeftJoin("talent_info", "talent_id = talent_info.id").
		OmitEmpty().Where("talent_id IN(?)", number).
		Fields("`platform_id`,`platform_account_id`,`platform_nickname`,`submit_date`,`fans_count`,`weibo_total_num`,`home_page_url`,`skilled_at`,`talent_id`,visit_store_region").
		Page(weibo.IndexPage, weibo.PageSize).OrderDesc("talent_id").Scan(&res)
	if err != nil {
		return nil, 0, err
	}
	var result []*backstage_model.ResponseWeiboFind
	err = g.DB().Model("platform_weibo_account_info").LeftJoin("talent_info", "talent_id = talent_info.id").OmitEmpty().Where("talent_id IN(?)", number).
		OrderDesc("talent_id").Scan(&result)
	if err != nil {
		return nil, 0, err
	}
	num := len(result)
	return res, num, nil
}

// FindByConditionWeibo 根据查询条件查询
func (s *serviceWeibo) FindByConditionWeibo(weibo *backstage_model.WeiboFind) ([]*backstage_model.ResponseWeiboFind, int, error) {
	var res []*backstage_model.ResponseWeiboFind
	if weibo.Weibo == nil {
		res, num, err := s.FindAllWeibo(weibo)
		if err != nil {
			return nil, 0, err
		}
		return res, num, nil
	}
	number, err := utils.RelyNumber(3)
	if err != nil {
		return nil, 0, err
	}
	g.DB().SetDebug(true)
	// 拼接数据库查询字符串语句
	contact := s.contact(weibo.Weibo)
	err = g.DB().Model("platform_weibo_account_info").LeftJoin("talent_info", "talent_id = talent_info.id").
		OmitEmpty().Where(contact).Where("talent_id IN(?)", number).Fields("`platform_id`,`platform_account_id`,`platform_nickname`,`submit_date`,`fans_count`,`weibo_total_num`,`home_page_url`,`skilled_at`,`talent_id`,visit_store_region").
		Page(weibo.IndexPage, weibo.PageSize).OrderDesc("talent_id").Scan(&res)
	if err != nil {
		return nil, 0, err
	}
	var result []*backstage_model.ResponseWeiboFind
	err = g.DB().Model("platform_weibo_account_info").LeftJoin("talent_info", "talent_id = talent_info.id").
		OmitEmpty().Where(contact).Where("talent_id IN(?)", number).
		Scan(&result)
	if err != nil {
		return nil, 0, err
	}
	num := len(result)
	return res, num, nil
}

// RemoveAccount 账号下架操作
func (s *serviceWeibo) RemoveAccount(status *backstage_model.RemoveAccountWeibo) error {
	g.DB().SetDebug(true)
	_, err := g.DB().Model("platform_weibo_account_info").
		Data(g.Map{"examine_status": "3", "examine_fail_reason": status.Message}).
		Where("platform_account_id", status.PlatformAccountId).Update()
	if err != nil {
		return err
	}
	return nil
}

// 拼接数据库数据库where语句字符串
func (s *serviceWeibo) contact(weibo *backstage_model.RequestWeiboFind) string {
	var res []string
	if weibo.PlatformAccountId != "" {
		res = append(res, "platform_account_id="+weibo.PlatformAccountId)
	}
	if weibo.TalentId != "" {
		res = append(res, "talent_id="+weibo.TalentId)
	}
	if len(weibo.SubmitDate) != 0 {
		res = append(res, "submit_date>'"+weibo.SubmitDate[0]+" 00:00:00' and "+
			"submit_date<'"+weibo.SubmitDate[1]+" 23:59:59'")
	}
	if len(weibo.FansCount) != 0 {
		res = append(res, "fans_count>="+weibo.FansCount[0]+" and fans_count<="+weibo.FansCount[1])
	}
	if weibo.VisitStoreRegion != "" {
		res = append(res, "visit_store_region="+weibo.VisitStoreRegion)
	}
	if len(weibo.SkilledAt) != 0 {
		// JSON_CONTAINS包含语句
		var temp string
		for index, value := range weibo.SkilledAt {
			if index == 0 {
				temp = "JSON_CONTAINS(skilled_at,'" + value + "')"
			} else {
				temp = " OR JSON_CONTAINS(skilled_at,'" + value + "')"
			}
		}
		res = append(res, "("+temp+")")
	}
	var result string
	for _, value := range res {
		result += " and " + value
	}
	return result
}

// FindAllById 单个查询所有
func (s *serviceWeibo) FindAllById(weibo *backstage_model.RemoveAccountWeibo) (*backstage_model.ResponsePlatformWeiboAccountInfo, error) {
	var res *backstage_model.ResponsePlatformWeiboAccountInfo
	err := g.DB().Model("platform_weibo_account_info").Where("talent_id", weibo.PlatformAccountId).Scan(&res)
	if err != nil {
		return nil, err
	}
	return res, nil
}
